# v0.2.0 (2021-08-26)

## Features

* Add support for custom validations

## Refactor

Refactored the codebase, simplifying the code. Only one mixin per feature
required now.


# v0.1.0 (2020-12-18)

Initial release
